pub type WithAmbient<F> = F;Expand description
Off the sim path ambient does not exist, so there is nothing to re-assert
per poll: the wrapper is the future itself. Under flash this is the
engine’s per-poll ambient re-assert wrapper.
pub type WithAmbient<F> = F;Off the sim path ambient does not exist, so there is nothing to re-assert
per poll: the wrapper is the future itself. Under flash this is the
engine’s per-poll ambient re-assert wrapper.