Module mpsc

Module mpsc 

Structs

Receiver
RecvError
An error returned from the recv function on a Receiver.
SendError
An error returned from the Sender::send or SyncSender::send function on channels.
Sender

Enums

TryRecvError
This enumeration is the list of the possible reasons that try_recv could not return data when called. This can occur with both a channel and a sync_channel.

Functions

channel
Create a new unbounded channel.