pub fn active_named_thread_count() -> usizeExpand description
Returns the number of currently active threads spawned via spawn_named.
pub fn active_named_thread_count() -> usizeReturns the number of currently active threads spawned via spawn_named.