BoxFuture

Type Alias BoxFuture 

pub type BoxFuture<'a, T> = Pin<Box<dyn Future<Output = T> + Send + 'a>>;
Boxed future that is Send on native, unrestricted on WASM.

Use as return type in trait methods to make the returned future Send-compatible on native (enabling tokio::spawn) while keeping WASM compatibility.

fn plan(&mut self) -> BoxFuture<'_, PlanOutcome<Self::Plan>>;

Aliased Type

pub struct BoxFuture<'a, T> { /* private fields */ }